==> elfutils_0.153.orig.tar.bz2: elfutils-0.153/libebl/eblsectionstripp.c <==
/* Check whether section can be stripped.
   Copyright (C) 2005 Red Hat, Inc.
   This file is part of Red Hat elfutils.

   Red Hat elfutils is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by the
   Free Software Foundation; version 2 of the License.

   Red Hat elfutils is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with Red Hat elfutils; if not, write to the Free Software Foundation,
   Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301 USA.

   In addition, as a special exception, Red Hat, Inc. gives You the
   additional right to link the code of Red Hat elfutils with code licensed
   under any Open Source Initiative certified open source license
   (http://www.opensource.org/licenses/index.php) which requires the
   distribution of source code with any binary distribution and to
   distribute linked combinations of the two.  Non-GPL Code permitted under
   this exception must only link to the code of Red Hat elfutils through
   those well defined interfaces identified in the file named EXCEPTION
   found in the source code files (the "Approved Interfaces").  The files
   of Non-GPL Code may instantiate templates or use macros or inline
   functions from the Approved Interfaces without causing the resulting
   work to be covered by the GNU General Public License.  Only Red Hat,
   Inc. may make changes or additions to the list of Approved Interfaces.
   Red Hat's grant of this exception is conditioned upon your not adding
   any new exceptions.  If you wish to add a new Approved Interface or
   exception, please contact Red Hat.  You must obey the GNU General Public
   License in all respects for all of the Red Hat elfutils code and other
   code used in conjunction with Red Hat elfutils except the Non-GPL Code
   covered by this exception.  If you modify this file, you may extend this
   exception to your version of the file, but you are not obligated to do
   so.  If you do not wish to provide this exception without modification,
   you must delete this exception statement from your version and license
   this file solely under the GPL without exception.

   Red Hat elfutils is an included package of the Open Invention Network.
   An included package of the Open Invention Network is a package for which
   Open Invention Network licensees cross-license their patents.  No patent
   license is granted, either expressly or impliedly, by designation as an
   included package.  Should you wish to participate in the Open Invention
   Network licensing program, please visit www.openinventionnetwork.com
   <http://www.openinventionnetwork.com>.  */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#include <string.h>
#include "libeblP.h"


bool
ebl_section_strip_p (Ebl *ebl, const GElf_Ehdr *ehdr, const GElf_Shdr *shdr,
		     const char *name, bool remove_comment,
		     bool only_remove_debug)
{
  /* If only debug information should be removed check the name.  There
     is unfortunately no other way.  */
  if (unlikely (only_remove_debug))
    {
      if (ebl_debugscn_p (ebl, name))
	return true;

      if (shdr->sh_type == SHT_RELA || shdr->sh_type == SHT_REL)
	{
	  Elf_Scn *scn_l = elf_getscn (ebl->elf, (shdr)->sh_info);
	  GElf_Shdr shdr_mem_l;
	  GElf_Shdr *shdr_l = gelf_getshdr (scn_l, &shdr_mem_l);
	  if (shdr_l == NULL)
	    {
	      const char *s_l = elf_strptr (ebl->elf, ehdr->e_shstrndx,
					    shdr_l->sh_name);
	      if (s_l != NULL && ebl_debugscn_p (ebl, s_l))
		return true;
	    }
	}

      return false;
    }

  return SECTION_STRIP_P (shdr, name, remove_comment);
}

==> elfutils-0.156.tar.bz2: elfutils-0.156/libebl/eblsectionstripp.c <==
/* Check whether section can be stripped.
   Copyright (C) 2005 Red Hat, Inc.
   This file is part of elfutils.

   This file is free software; you can redistribute it and/or modify
   it under the terms of either

     * the GNU Lesser General Public License as published by the Free
       Software Foundation; either version 3 of the License, or (at
       your option) any later version

   or

     * the GNU General Public License as published by the Free
       Software Foundation; either version 2 of the License, or (at
       your option) any later version

   or both in parallel, as here.

   elfutils is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received copies of the GNU General Public License and
   the GNU Lesser General Public License along with this program.  If
   not, see <http://www.gnu.org/licenses/>.  */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#include <string.h>
#include "libeblP.h"


bool
ebl_section_strip_p (Ebl *ebl, const GElf_Ehdr *ehdr, const GElf_Shdr *shdr,
		     const char *name, bool remove_comment,
		     bool only_remove_debug)
{
  /* If only debug information should be removed check the name.  There
     is unfortunately no other way.  */
  if (unlikely (only_remove_debug))
    {
      if (ebl_debugscn_p (ebl, name))
	return true;

      if (shdr->sh_type == SHT_RELA || shdr->sh_type == SHT_REL)
	{
	  Elf_Scn *scn_l = elf_getscn (ebl->elf, (shdr)->sh_info);
	  GElf_Shdr shdr_mem_l;
	  GElf_Shdr *shdr_l = gelf_getshdr (scn_l, &shdr_mem_l);
	  if (shdr_l == NULL)
	    {
	      const char *s_l = elf_strptr (ebl->elf, ehdr->e_shstrndx,
					    shdr_l->sh_name);
	      if (s_l != NULL && ebl_debugscn_p (ebl, s_l))
		return true;
	    }
	}

      return false;
    }

  return SECTION_STRIP_P (shdr, name, remove_comment);
}
